@@ -70,7 +70,7 @@ def get_news_sentiment(ticker_list):
 
             news_list.append([tick, date, time, text])
 
-    vader = SentimentIntensityAnalyzer()
+    vader = SentimentIntensityAnalyzer()  # type: ignore
 
     columns = ["ticker", "date", "time", "headline"]
 
@@ -277,11 +277,7 @@ def get_fred_data(series_list, config, quarters=True):
         if df_fred.shape[0] > 0:
             s = s.drop(columns="end_date")
             df_fred = pd.merge(
-                df_fred,
-                s,
-                how="inner",
-                left_on="quarter",
-                right_on="quarter",
+                df_fred, s, how="inner", left_on="quarter", right_on="quarter"
             )
         else:
             df_fred = s
@@ -305,9 +301,9 @@ def append_price_data(df):
     df_prices = df_prices.groupby("end_date_CALENDAR_QUARTER").last().reset_index()
 
     # fiscal_quarter
-    df = df_filter(df, "period_duration_type", ["fiscal_quarter"])
+    df = df_filter(df, "period_duration_type", ["fiscal_quarter"])  # type: ignore
     dates = list(set(list(df["end_date_CALENDAR_QUARTER"])))
-    df_p = df_filter(df_prices, "end_date_CALENDAR_QUARTER", dates)
+    df_p = df_filter(df_prices, "end_date_CALENDAR_QUARTER", dates)  # type: ignore
 
     df_p.columns = ["end_date_CALENDAR_QUARTER", "end_date", "value"]
     df_p["ticker"] = ticker
@@ -745,9 +741,7 @@ def rolling_r_squared(
     ]  # [['period_name','value','earnings_date','alpha_10_day']]
     time_series_description = df.iloc[0]["time_series_description"]
     model = RollingOLS.from_formula(
-        "value ~ " + str(y_name),
-        data=df[["value", y_name]],
-        window=window,
+        "value ~ " + str(y_name), data=df[["value", y_name]], window=window
     )
     rres = model.fit()
     df["intercept"] = rres.params[["Intercept"]]
