@@ -4,6 +4,7 @@ Utilities module
 from enum import Enum
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 import pandas as pd
+import canalyst_candas
 from canalyst_candas.configuration.exceptions import ConfigException
 from python_graphql_client import GraphqlClient
 import numpy as np
@@ -60,11 +61,15 @@ BRAND_CONFIG_DEFAULTS = {
     "figure_bg_color": "#FFFFFF",
     "vertical_line_color": "#E2E3E3",
     "ax_spine_color": "#C3C2C3",
-    "title_font_path": "canalyst_candas/fonts/Barlow-SemiBold.ttf",
-    "body_font_path": "canalyst_candas/fonts/Roboto-Regular.ttf",
+    "title_font_path": Path(
+        os.path.dirname(canalyst_candas.__file__) + "/fonts/Barlow-SemiBold.ttf"
+    ),
+    "body_font_path": Path(
+        os.path.dirname(canalyst_candas.__file__) + "/fonts/Roboto-Regular.ttf"
+    ),
     "chart_bg_color": "#161B21",
     "font_color": "#000",
-    "logo_path": os.getcwd() + "/canalyst_candas/images/logo.png",
+    "logo_path": Path(os.path.dirname(canalyst_candas.__file__) + "/images/logo.png"),
 }
 
 
@@ -202,10 +207,24 @@ class Getter:
             return None
         return df
 
+    def get_parquet_from_s3(self, file_name):
+
+        """
+        Get parquet from S3
+        """
+        # try:
+        import io
+
+        csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
+        df = pd.read_parquet(io.BytesIO(csv_obj["Body"].read()))
+        # except:
+        #    return None
+        return df
+
     def get_pickle_from_s3(self, file_name):
 
         """
-        Get CSV from S3
+        Get pickle from S3
         """
         try:
             csv_obj = self.s3_client.get_object(Bucket="candas", Key=file_name)
@@ -215,7 +234,8 @@ class Getter:
             return None
         return df
 
-    def get_file(self, ticker, type):  # returns a dataframe
+    def get_file(self, ticker, type, file_type):  # returns a dataframe
+        df = None
         """
         Gets ticker file from S3
 
@@ -223,15 +243,22 @@ class Getter:
         """
         file_ticker = ticker.split(" ")[0]
 
-        path_name = (
-            f"DATA/{file_ticker}/{ticker}_{type}.pickle"  # first try pickel on s3
-        )
-        df = self.get_pickle_from_s3(path_name)
+        if file_type == "pickle":
+            path_name = (
+                f"DATA/{file_ticker}/{ticker}_{type}.pickle"  # first try pickel on s3
+            )
+            df = self.get_pickle_from_s3(path_name)
+            return df
+
+        if file_type == "parquet":
+
+            path_name = f"DATA/{file_ticker}/{ticker}_{type}.parquet"
+            df = self.get_parquet_from_s3(path_name)
+            return df
 
         if df is None:
-            path_name = (
-                f"DATA/{file_ticker}/{ticker}_{type}.csv"  # if no pickel, try csv on s3
-            )
+
+            path_name = f"DATA/{file_ticker}/{ticker}_{type}.csv"
             df = self.get_csv_from_s3(path_name)
 
         if df is None:
@@ -258,6 +285,7 @@ def get_data_set_from_mds(
 
     Different types of CSVs are available, listed in the CsvDataKeys enum.
     """
+
     url_candidates = _get_data_set_urls_from_mds(
         csin, model_version, auth_headers, log, mds_host
     )
